@@ -2,7 +2,7 @@
 #
 # Workbook - A class for writing the Excel XLSX Workbook file.
 #
-# Copyright 2013-2019, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2020, John McNamara, jmcnamara@cpan.org
 #
 
 # Standard packages.
@@ -37,7 +37,6 @@ from .chart_scatter import ChartScatter
 from .chart_stock import ChartStock
 from .exceptions import InvalidWorksheetName
 from .exceptions import DuplicateWorksheetName
-from .exceptions import ReservedWorksheetName
 from .exceptions import UndefinedImageSize
 from .exceptions import UnsupportedImageFormat
 from .exceptions import FileCreateError
@@ -136,6 +135,7 @@ class Workbook(xmlwriter.XMLwriter):
         self.calc_on_load = True
         self.allow_zip64 = False
         self.calc_id = 124519
+        self.has_comments = False
 
         # We can't do 'constant_memory' mode while doing 'in_memory' mode.
         if self.in_memory:
@@ -321,6 +321,8 @@ class Workbook(xmlwriter.XMLwriter):
                                     "Use workbook.use_zip64().")
 
             self.fileclosed = True
+        else:
+            warn("Calling close() on already closed file.")
 
     def set_size(self, width, height):
         """
@@ -791,11 +793,6 @@ class Workbook(xmlwriter.XMLwriter):
                 "Sheet name cannot start or end with an apostrophe \"%s\"." %
                 sheetname)
 
-        # Check that sheetname isn't the reserved work "History".
-        if sheetname.lower() == 'history':
-            raise ReservedWorksheetName(
-                "Worksheet name 'History' is reserved by Excel")
-
         # Check that the worksheet name doesn't already exist since this is a
         # fatal Excel error. The check must be case insensitive like Excel.
         for worksheet in self.worksheets():
@@ -1499,6 +1496,7 @@ class Workbook(xmlwriter.XMLwriter):
                 if sheet.has_comments:
                     comment_files += 1
                     comment_id += 1
+                    self.has_comments = True
 
                 vml_drawing_id += 1
 
@@ -1520,12 +1518,6 @@ class Workbook(xmlwriter.XMLwriter):
             self.num_vml_files = vml_files
             self.num_comment_files = comment_files
 
-        # Add a font format for cell comments.
-        if comment_files > 0:
-            xf = self.add_format({'font_name': 'Tahoma', 'font_size': 8,
-                                  'color_indexed': 81, 'font_only': True})
-            xf._get_xf_index()
-
     def _prepare_tables(self):
         # Set the table ids for the worksheet tables.
         table_id = 0
